#include <QMainWindow>
#include <QPainter>
#include <QPrintPreviewDialog>
#include <QPrintDialog>
#include <QPrinter>
#include <QDebug>
#include <QApplication>
#include <QMenuBar>
#include <QMenu>
#include <QAction>
#include <QFontMetrics>
#include <QDateTime>
#include <QWebView>

static QString buildStr()
{
    QString t = QT_VERSION_STR;
#if QT_VERSION >= 0x050000
    t += ' ' + QGuiApplication::platformName();
#endif
    return t;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow() { delete m_printer; }

private slots:
    void slotPrintPreview();
    void slotPrintDialog();
    void printTest(QPrinter *p);

private:
    QPrinter *m_printer;
    QWebView *m_webView;
};

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , m_printer(new QPrinter)
    , m_webView(new QWebView(this))
{
    m_printer->setPaperSize(QPrinter::A4);
    m_printer->setOrientation(QPrinter::Landscape);
    m_printer->setFullPage(true);
    m_printer->setPageMargins(0,0,0,0,QPrinter::Millimeter);

    setWindowTitle(buildStr());
    QMenu *fileMenu = menuBar()->addMenu("File");
    fileMenu->setObjectName("fileMenu");

    QAction *sa = fileMenu->addAction("Print Setup");
    connect(sa, SIGNAL(triggered()), this, SLOT(slotPrintDialog()));

    QAction *pa = fileMenu->addAction("Print");
    pa->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_P));
    connect(pa, SIGNAL(triggered()), this, SLOT(slotPrintPreview()));

    QAction *qa = fileMenu->addAction("Quit");
    qa->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q));
    connect(qa, SIGNAL(triggered()), qApp, SLOT(quit()));

    setCentralWidget(m_webView);
    m_webView->load(QUrl("qrc:/demo.html"));
}

void MainWindow::slotPrintDialog()
{
    QPrintDialog dlg(m_printer, this);
    dlg.exec();
}

void MainWindow::slotPrintPreview()
{
    QPrintPreviewDialog ppd(m_printer,  this);
    connect(&ppd,SIGNAL(paintRequested(QPrinter*)),this,SLOT(printTest(QPrinter*)));
    ppd.exec();
}

void MainWindow::printTest(QPrinter *p)
{
    m_webView->print(p);
}

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    MainWindow w;
    qDebug() << buildStr();
    w.move(400, 400);
    w.show();

    return a.exec();
}

#include "main.moc"
